class Versioned(object):
    HISTORY_CLASS_MAP = {}
    __versioned__ = {}
    __pending_versioned__ = []
